import { ElementRef, EventEmitter } from '@angular/core';
/**
 * Represents individual resizable/collapsible panes.
 * @igxModule IgxSplitterModule
 *
 * @igxParent IgxSplitterComponent
 *
 * @igxKeywords pane
 *
 * @igxGroup presentation
 *
 * @remarks
 *  Users can control the resize behavior via the min and max size properties.
 */
export declare class IgxSplitterPaneComponent {
    private el;
    private _size;
    private _collapsed;
    /** @hidden @internal */
    owner: any;
    /**
     * Gets/Sets the size of the current pane.
     *  * @example
     * ```html
     * <igx-splitter>
     *  <igx-splitter-pane [size]='size'>...</igx-splitter-pane>
     * </igx-splitter>
     * ```
     */
    get size(): string;
    set size(value: string);
    /**
     * Gets/Sets the minimum allowed size of the current pane.
     * @example
     * ```html
     * <igx-splitter>
     *  <igx-splitter-pane [minSize]='minSize'>...</igx-splitter-pane>
     * </igx-splitter>
     * ```
     */
    minSize: string;
    /**
     * Gets/Set the maximum allowed size of the current pane.
     * @example
     * ```html
     * <igx-splitter>
     *  <igx-splitter-pane [maxSize]='maxSize'>...</igx-splitter-pane>
     * </igx-splitter>
     * ```
     */
    maxSize: string;
    /**
     * Gets/Sets whether pane is resizable.
     * @example
     * ```html
     * <igx-splitter>
     *  <igx-splitter-pane [resizable]='false'>...</igx-splitter-pane>
     * </igx-splitter>
     * ```
     * @remarks
     * If pane is not resizable its related splitter bar cannot be dragged.
     */
    resizable: boolean;
    /**
     * Event fired when collapsed state of pane is changed.
     * @example
     * ```html
     * <igx-splitter>
     *  <igx-splitter-pane (onToggle)='onPaneToggle($event)'>...</igx-splitter-pane>
     * </igx-splitter>
     * ```
     */
    onToggle: EventEmitter<IgxSplitterPaneComponent>;
    /** @hidden @internal */
    order: number;
    /**
     *
     * @hidden @internal
     * Gets the host native element.
     */
    get element(): any;
    /**
     * @hidden @internal
     * Gets/Sets the `overflow`.
     */
    overflow: string;
    /**
     * @hidden @internal
     * Gets/Sets the `minHeight` and `minWidth` properties of the current pane.
     */
    minHeight: number;
    /**
     * @hidden @internal
     * Gets/Sets the `maxHeight` and `maxWidth` properties of the current `IgxSplitterPaneComponent`.
     */
    maxHeight: string;
    /**
     * @hidden @internal
     * Gets the `flex` property of the current `IgxSplitterPaneComponent`.
     */
    get flex(): string;
    /**
     * @hidden @internal
     * Gets/Sets the 'display' property of the current pane.
     */
    display: string;
    /**
     * Gets/Sets whether current pane is collapsed.
     * @example
     * ```typescript
     * const isCollapsed = pane.collapsed;
     * ```
     */
    set collapsed(value: boolean);
    get collapsed(): boolean;
    /** @hidden @internal */
    private _getSiblings;
    /**
     * Toggles the collapsed state of the pane.
     * @example
     * ```typescript
     * pane.toggle();
     * ```
     */
    toggle(): void;
    constructor(el: ElementRef);
}
